from __future__ import unicode_literals

# Colors definitions
colors = {
    "OK":        "\033[92m",
    "INFO":      "\033[93m",
    "ERROR":     "\033[31m",
    "TITLE":     "\033[93m",
    "TEXT":      "\033[0m",
    "VULN":      "\033[31m",
    "NOTVULN":   "\033[92m",
    "REDIR":     "\033[0m",
    "PARSED":    "\033[0m",
    "TITNOBULL": "\033[93m",
    "ADDITIONS": "\033[90m"
}

# Chars definitions
chars = {
    "OK":        "\u2713",
    "INFO":      "i",
    "ERROR":     "\u2717",
    "TITLE":     "*",
    "TEXT":      "",
    "VULN":      "\u2717",
    "NOTVULN":   "\u2713",
    "REDIR":     "\u2794",
    "PARSED":    "\u26AD",
    "TITNOBULL": "",
    "ADDITIONS": ""
}